public class Arraz {

    public int sumValuesOfArray(int[] arr) {
        int sum = 0;

        for (int i : arr) {
            sum += i;
        }

        return sum;

    }

    public double sumDoublesOfArray(double[] arr) {
        double sum = 0;

        for (double d : arr) {
            sum += d;
        }

        return sum;

    }


    public int averageOfArray(int[] arr) {
        int sum = 0;

        for (int i : arr) {
            sum += i;
        }

        return (sum / arr.length);
    }


    public double doubleAverageOfArray(double[] arr3) {

        double sum = 0;

        for (double i : arr3) {
            sum += i;
        }

        return (sum / arr3.length);

    }


    public boolean containsValue(int[] arr, int value) {

        for (int i : arr){
            if ( i == value){
                return true;
            }
        }
        return false;
    }


    public int[] reverseArray(int[] array1) {
        int[] array2 = new int[array1.length];

        for (int i = 0; i < array1.length; i++){
            array2[array1.length - 1 - i] = array1[i];
        }

        return array2;
    }

    public class OddEven{
        public int odds;
        public int evens;

        public int getOdds() {
            return odds;
        }

        public int getEvens() {
            return evens;
        }
    }



}
